/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.states.sq;

import org.dive4elements.artifactdatabase.state.DefaultFacet;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.Artifact;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.math.fitting.Function;
import org.dive4elements.river.artifacts.math.fitting.FunctionFactory;
import org.dive4elements.river.artifacts.model.sq.SQFunction;
import org.dive4elements.river.artifacts.model.sq.StaticSQRelation;


public class StaticSQRelationFacet
extends DefaultFacet
implements Facet
{
    public static final String FUNCTION = "sq-pow";

    private StaticSQRelation relation;


    public StaticSQRelationFacet(
        int ndx,
        String name,
        String description,
        StaticSQRelation relation) {
        super(ndx, name, description);
        this.relation = relation;
    }

    @Override
    public Object getData(Artifact artifact, CallContext context) {
        double qmax = relation.getQmax();
        double[] coeffs = new double[] {relation.getA(), relation.getB()};
        Function func = FunctionFactory.getInstance().getFunction(FUNCTION);
        org.dive4elements.river.artifacts.math.Function function =
            func.instantiate(coeffs);
        SQFunction sqf = new SQFunction(function, 0, qmax);
        return sqf;
    }

    @Override
    public Facet deepCopy() {
        StaticSQRelationFacet copy =
            new StaticSQRelationFacet(index, name, description, relation);
        copy.set(this);
        return copy;
    }
}
